@@ -18,7 +18,7 @@ function generate_testr_results {
     if [ -f .testrepository/0 ]; then
         sudo .tox/functional/bin/testr last --subunit > $WORKSPACE/testrepository.subunit
         sudo mv $WORKSPACE/testrepository.subunit $BASE/logs/testrepository.subunit
-        sudo .tox/functional/bin/python /usr/local/jenkins/slave_scripts/subunit2html.py $BASE/logs/testrepository.subunit $BASE/logs/testr_results.html
+        sudo /usr/os-testr-env/bin/subunit2html $BASE/logs/testrepository.subunit $BASE/logs/testr_results.html
         sudo gzip -9 $BASE/logs/testrepository.subunit
         sudo gzip -9 $BASE/logs/testr_results.html
         sudo chown jenkins:jenkins $BASE/logs/testrepository.subunit.gz $BASE/logs/testr_results.html.gz
@@ -30,10 +30,11 @@ export NOVACLIENT_DIR="$BASE/new/python-novaclient"
 
 sudo chown -R jenkins:stack $NOVACLIENT_DIR
 
-# ensure clouds.yaml exists
-mkdir -p ~/.config/openstack
-sudo cp -a ~stack/.config/openstack/clouds.yaml ~/.config/openstack
-sudo chown -R jenkins:stack ~/.config/openstack
+# FIXME(melwitt): Currently, novaclient requires version in the
+# auth url in order to work and it doesn't support keystone v3.
+# Use v2.0 in the auth url in clouds.yaml to enable the functional
+# test job to work until novaclient is updated to support v3
+sudo sed -i -e 's/auth_url: \([^v ]\+\)\(\/v[0-9]\+\.\?[0-9]*\)\?$/auth_url: \1\/v2.0/g' /etc/openstack/clouds.yaml
 
 # Go to the novaclient dir
 cd $NOVACLIENT_DIR
